@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::ActionCommand;
-$Footprintless::App::ActionCommand::VERSION = '1.13';
+$Footprintless::App::ActionCommand::VERSION = '1.14';
 # ABSTRACT: A base class for action commands
 # PODNAME: Footprintless::App::ActionCommand
 
@@ -24,18 +24,25 @@ sub _default_action {
 sub description {
     my ($self) = @_;
 
-    if ( $self->{action} ) {
+    if ( $self->{action} && !$self->{is_default_action} ) {
         return $self->{action}->description();
     }
     else {
         require Footprintless::App::DocumentationUtil;
         my $pod_description = Footprintless::App::DocumentationUtil::description($self);
         my %actions         = $self->_actions();
+
+        my $default_action = $self->_default_action();
+        $default_action =
+            $default_action
+            ? "\n\nDefault action: $default_action"
+            : '';
+
         return
               $pod_description
             . "\nAvailable actions:\n\n"
-            . $self->_format_actions( $self->_actions() );
-        return $pod_description . "\n";
+            . $self->_format_actions( $self->_actions() )
+            . $default_action;
     }
 }
 
@@ -68,7 +75,15 @@ sub prepare {
 
     my ( $coordinate, $action_name, my @action_args ) = @$remaining_args;
     $fields{coordinate} = $coordinate;
-    $fields{action_name} = $action_name || $class->_default_action();
+
+    if ($action_name) {
+        $fields{action_name} = $action_name;
+    }
+    else {
+        $fields{action_name}       = $class->_default_action();
+        $fields{is_default_action} = 1;
+    }
+
     if ( $fields{action_name} ) {
         my %actions = $class->_actions();
         my $action  = $actions{ $fields{action_name} };
@@ -92,7 +107,9 @@ sub prepare {
 
 sub usage {
     my ($self) = @_;
-    return $self->{action} ? $self->{action}->usage() : $self->{usage};
+    return ( $self->{action} && !$self->{is_default_action} )
+        ? $self->{action}->usage()
+        : $self->{usage};
 }
 
 sub validate_args {
@@ -121,7 +138,7 @@ Footprintless::App::ActionCommand - A base class for action commands
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 AUTHOR
 
